#
# spec file for package libqt5-qtspeech
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define qt5_snapshot 1
%define libname libQt5TextToSpeech5
%define base_name libqt5
%define real_version 5.15.14
%define so_version 5.15.14
%define tar_version qtspeech-everywhere-src-%{version}
Name:           libqt5-qtspeech
VCS: https://src.suse.de/SLFO-pool/libqt5-qtspeech#9af57d70796733a360a2f3ed698d1a6487445e80ca06a7519294fc4abe83c01c
Version:        5.15.14+kde1
Release:        160000.1.7
Summary:        Qt 5 Speech Addon
License:        LGPL-3.0-only OR (GPL-2.0-only OR GPL-3.0-or-later)
Group:          Development/Libraries/X11
URL:            https://www.qt.io
Source:         %{tar_version}.tar.xz
Source1:        baselibs.conf
BuildRequires:  fdupes
BuildRequires:  libQt5Core-private-headers-devel
BuildRequires:  libQt5Widgets-devel
BuildRequires:  libspeechd-devel
BuildRequires:  xz
%if %{qt5_snapshot}
#to create the forwarding headers
BuildRequires:  perl
%endif

%description
Qt is a set of libraries for developing applications.

The module enables a Qt application to support accessibility features
such as text-to-speech, which is useful for end-users who are visually
challenged or cannot access the application for whatever reason.

%prep
%autosetup -p1 -n %{tar_version}
%if 0%{?suse_version} < 1330
# work around wrong include directory specification in speech-dispatcher's pkgconfig file in Leap 42.x
sed -i "s|libspeechd.h|speech-dispatcher/libspeechd.h|" src/plugins/tts/speechdispatcher/qtexttospeech_speechd.*
%endif

%package -n %{libname}
Summary:        Qt 5 Speech Addon
Group:          System/Libraries
%requires_eq    libQt5Core5

%description -n %{libname}
Qt is a set of libraries for developing applications.

The module enables a Qt application to support accessibility features
such as text-to-speech, which is useful for end-users who are visually
challenged or cannot access the application for whatever reason.

%package plugin-speechd
Summary:        Qt5 Speech Module - Speech Dispatcher support
Group:          System/Libraries
Requires:       %{libname} = %{version}
Supplements:    (speech-dispatcher and %{libname})

%description plugin-speechd
This plugin adds support for using speech-dispatcher for speech synthesis
with the Qt5 Speech module.

%package devel
Summary:        Development files for the Qt5 Speech library
Group:          Development/Libraries/X11
Requires:       %{libname} = %{version}

%description devel
You need this package if you want to compile programs with qtspeech.

%package examples
Summary:        Qt5 Speech examples
Group:          Development/Libraries/X11
License:        BSD-3-Clause

%description examples
Examples for the libqt5-qtspeech module.

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%build
%if %{qt5_snapshot}
#force the configure script to generate the forwarding headers (it checks whether .git directory exists)
mkdir .git
%endif
%qmake5
%make_jobs

%install
%qmake5_install

# kill .la files
rm -f %{buildroot}%{_libqt5_libdir}/lib*.la

%files -n %{libname}
%license LICENSE.*
%{_libqt5_libdir}/libQt5TextToSpeech.so.*
%dir %{_libqt5_plugindir}/texttospeech/

%files plugin-speechd
%{_libqt5_plugindir}/texttospeech/libqtexttospeech_speechd.so
%dir %{_libqt5_libdir}/cmake/Qt5TextToSpeech/
%{_libqt5_libdir}/cmake/Qt5TextToSpeech/Qt5TextToSpeech_QTextToSpeechPluginSpeechd.cmake

%files devel
%{_libqt5_archdatadir}/mkspecs/modules/qt_lib_*.pri
%{_libqt5_includedir}/Qt*
%dir %{_libqt5_libdir}/cmake/Qt5TextToSpeech/
%{_libqt5_libdir}/cmake/Qt5TextToSpeech/Qt5TextToSpeechConfig.cmake
%{_libqt5_libdir}/cmake/Qt5TextToSpeech/Qt5TextToSpeechConfigVersion.cmake
%{_libqt5_libdir}/libQt5TextToSpeech.prl
%{_libqt5_libdir}/libQt5TextToSpeech.so
%{_libqt5_libdir}/pkgconfig/Qt5TextToSpeech.pc

%files examples
%{_libqt5_examplesdir}/

%changelog
* Wed May 29 2024 fabian@ritter-vogt.de
- Update to version 5.15.14+kde1, rebased upstream:
  * Bump version to 5.15.14
* Tue Mar 19 2024 fabian@ritter-vogt.de
- Update to version 5.15.13+kde1, rebased upstream:
  * Bump version to 5.15.13
* Fri Dec 29 2023 fabian@ritter-vogt.de
- Update to version 5.15.12+kde1, rebased upstream:
  * Bump version to 5.15.12
* Fri Oct  6 2023 fabian@ritter-vogt.de
- Update to version 5.15.11+kde1, rebased upstream:
  * No code changes
* Tue Jun 13 2023 fabian@ritter-vogt.de
- Update to version 5.15.10+kde1, rebased upstream:
  * No code changes
* Fri Apr 21 2023 fabian@ritter-vogt.de
- Update to version 5.15.8+kde4, rebased upstream:
  * Fix QtSpeech example querying locales before initialising
* Mon Jan  9 2023 fabian@ritter-vogt.de
- Update to version 5.15.8+kde1, rebased upstream:
  * No code changes
* Thu Nov  3 2022 fabian@ritter-vogt.de
- Update to version 5.15.7+kde1, rebased upstream:
  * Android: Protect against a null Locale object when calling getLocale
* Mon Sep 26 2022 fabian@ritter-vogt.de
- Update to version 5.15.6+kde1, rebased upstream:
  * No code changes
* Mon Jun 27 2022 fabian@ritter-vogt.de
- Update to version 5.15.5+kde1, rebased upstream:
  * Reverse list of voices before returning from Speech-Dispatcher
  * Revert "Update commercial license headers"
  * Update commercial license headers
- Drop 0001-Revert-Bump-version.patch, it's versioned correctly now
* Tue Jun 22 2021 fabian@ritter-vogt.de
- Switch to KDE's maintenance branch
- Update to version 5.15.2+kde2:
  * Add changes file for Qt 5.15.2
  * Bump version
- Add patch to reset version to 5.15.2:
  * 0001-Revert-Bump-version.patch
* Fri Nov 20 2020 fabian@ritter-vogt.de
- Update to 5.15.2:
  * New bugfix release
  * For more details please see:
    http://code.qt.io/cgit/qt/qtspeech.git/plain/dist/changes-5.15.2/?h=5.15.2
* Thu Sep 10 2020 fabian@ritter-vogt.de
- Update to 5.15.1:
  * New bugfix release
  * For more details please see:
    http://code.qt.io/cgit/qt/qtspeech.git/plain/dist/changes-5.15.1/?h=5.15.1
* Tue May 26 2020 callumjfarmer13@gmail.com
- Update to version 5.15.0:
  * No changelog available
* Wed May 20 2020 callumjfarmer13@gmail.com
- Update to version 5.15.0-rc2:
  * No changelog available
* Wed May  6 2020 fabian@ritter-vogt.de
- Update to 5.15.0-rc:
  * New bugfix release
  * For the changes between 5.14.2 and 5.15.0 please see:
    http://code.qt.io/cgit/qt/qtspeech.git/plain/dist/changes-5.15.0/?h=5.15.0
* Sun Apr 26 2020 fabian@ritter-vogt.de
- Move the speechd plugin's cmake file into the plugin subpackage
* Fri Apr 24 2020 fabian@ritter-vogt.de
- Update to 5.15.0-beta4:
  * New bugfix release
  * No changelog available
* Tue Apr 14 2020 fabian@ritter-vogt.de
- Update to 5.15.0-beta3:
  * New bugfix release
  * No changelog available
* Tue Mar 24 2020 fabian@ritter-vogt.de
- Update to 5.15.0-beta2:
  * New bugfix release
  * No changelog available
* Fri Feb 28 2020 fabian@ritter-vogt.de
- Update to 5.15.0-beta1:
  * New bugfix release
  * No changelog available
* Wed Feb 19 2020 fabian@ritter-vogt.de
- Update to 5.15.0-alpha:
  * New feature release
  * For more details please see:
    https://wiki.qt.io/New_Features_in_Qt_5.15
* Mon Jan 27 2020 fabian@ritter-vogt.de
- Update to 5.14.1:
  * New bugfix release
  * For more details please see:
    http://code.qt.io/cgit/qt/qtspeech.git/plain/dist/changes-5.14.1/?h=v5.14.1
* Tue Dec 17 2019 christophe@krop.fr
- Update the license tags.
* Thu Dec 12 2019 fabian@ritter-vogt.de
- Update to 5.14.0:
  * New bugfix release
  * For the changes between 5.13.2 and 5.14.0 please see:
    https://code.qt.io/cgit/qt/qtspeech.git/tree/dist/changes-5.14.0?h=v5.14.0
  * For the changes between 5.13.1 and 5.13.2 please see:
    https://code.qt.io/cgit/qt/qtspeech.git/tree/dist/changes-5.13.2?h=v5.14.0
* Wed Dec  4 2019 fabian@ritter-vogt.de
- Update to 5.14.0-rc:
  * New bugfix release
  * No changelog available
  * For more details please see:
  * For more details about Qt 5.14 please see:
    https://wiki.qt.io/New_Features_in_Qt_5.14
* Tue Nov 12 2019 fabian@ritter-vogt.de
- Update to 5.14.0-beta3:
  * New bugfix release
  * No changelog available
* Thu Oct 24 2019 fabian@ritter-vogt.de
- Update to 5.14.0-beta2:
  * New bugfix release
  * No changelog available
* Tue Oct 15 2019 fabian@ritter-vogt.de
- Update to 5.14.0-beta1:
  * New bugfix release
  * No changelog available
* Mon Sep 30 2019 fabian@ritter-vogt.de
- Update to 5.14.0-alpha:
  * New feature release
  * No changelog available
  * For more details about Qt 5.14 please see:
    https://wiki.qt.io/New_Features_in_Qt_5.14
* Fri Sep  6 2019 fabian@ritter-vogt.de
- Update to 5.13.1:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtspeech.git/plain/dist/changes-5.13.1/?h=v5.13.1
* Wed Jun 19 2019 fabian@ritter-vogt.de
- Update to 5.13.0:
  * New bugfix release
  * No changelog available
  * For more details about Qt 5.13 please see:
  * http://code.qt.io/cgit/qt/qtspeech.git/plain/dist/changes-5.13.0/?h=5.13
* Tue Jun  4 2019 fabian@ritter-vogt.de
- Update to 5.13.0-rc:
  * New bugfix release
  * No changelog available
* Mon Apr 29 2019 fabian@ritter-vogt.de
- Update to 5.13.0-beta2:
  * New bugfix release
  * No changelog available
* Thu Apr 18 2019 fabian@ritter-vogt.de
- Update to 5.12.3:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtspeech.git/plain/dist/changes-5.12.3/?h=v5.12.3
* Thu Mar 21 2019 fabian@ritter-vogt.de
- Update to 5.13.0-beta1:
  * New feature release
  * For more details about Qt 5.13 please see:
  * http://code.qt.io/cgit/qt/qtspeech.git/plain/dist/changes-5.13.0/?h=5.13
* Thu Mar 14 2019 fabian@ritter-vogt.de
- Update to 5.12.2:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtspeech.git/plain/dist/changes-5.12.2/?h=5.12.2
* Mon Feb 11 2019 fabian@ritter-vogt.de
- Add packageand(speech-dispatcher:%%{libname}) supplements to the speechd plugin
- Add the plugin to baselibs.conf
* Fri Feb  1 2019 fabian@ritter-vogt.de
- Update to 5.12.1:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtspeech.git/plain/dist/changes-5.12.1/?h=v5.12.1
* Wed Jan 30 2019 fabian@ritter-vogt.de
- Split speechd plugin into subpackage to not pull in libspeechd forcibly
- Use System/Libraries as group for libQt5TextToSpeech5
- Use %%license
- Use %%requires_eq due to private API use
* Thu Dec  6 2018 fabian@ritter-vogt.de
- Update to 5.12.0:
  * New feature release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtspeech.git/plain/dist/changes-5.12.0/?h=v5.12.0
* Mon Dec  3 2018 fabian@ritter-vogt.de
- Update to 5.12.0-rc2:
  * New bugfix release
  * Only important bugfixes
- Changelog for Qt 5.12.0:
  * http://code.qt.io/cgit/qt/qtspeech.git/plain/dist/changes-5.12.0/?h=5.12.0
* Thu Nov 22 2018 fabian@ritter-vogt.de
- Update to 5.12.0-rc:
  * New bugfix release
  * No changelog available
* Thu Nov  8 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta4:
  * New bugfix release
  * No changelog available
* Fri Oct 26 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta3:
  * New bugfix release
  * No changelog available
* Wed Oct 17 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta2:
  * New bugfix release
  * No changelog available
* Fri Oct  5 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta1:
  * New bugfix release
  * No changelog available
* Tue Oct  2 2018 fabian@ritter-vogt.de
- Update to 5.12.0-alpha:
  * New feature release
  * For more details please see:
  * http://wiki.qt.io/New_Features_in_Qt_5.12
* Fri Sep 21 2018 fabian@ritter-vogt.de
- Update to 5.11.2
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtspeech.git/plain/dist/changes-5.11.2/?h=v5.11.2
* Tue Jun 19 2018 fabian@ritter-vogt.de
- Update to 5.11.1
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtspeech.git/plain/dist/changes-5.11.1/?h=v5.11.1
* Tue May 22 2018 fabian@ritter-vogt.de
- Update to 5.11.0
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtspeech.git/plain/dist/changes-5.11.0/?h=v5.11.0
* Tue May  8 2018 fabian@ritter-vogt.de
- Update to 5.11.0-rc
  * New bugfix release
  * No changelog available
* Mon Apr 23 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta4
  * New bugfix release
  * No changelog available
* Wed Apr 11 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta3
  * New bugfix release
  * No changelog available
* Wed Mar 28 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta2
  * New bugfix release
  * No changelog available
* Tue Mar 13 2018 christophe@krop.fr
- Fix the license tag.
* Thu Mar  1 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta1
  * New feature release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtspeech.git/plain/dist/changes-5.11.0-beta1/?h=v5.11.0-beta1
* Tue Feb 20 2018 fabian@ritter-vogt.de
- Update to 5.11.0-alpha
  * New feature release
  * For more details please see:
  * https://wiki.qt.io/New_Features_in_Qt_5.11
* Wed Feb 14 2018 fabian@ritter-vogt.de
- Update to 5.10.1
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtspeech.git/plain/dist/changes-5.10.1/?h=v5.10.1
* Thu Dec  7 2017 fabian@ritter-vogt.de
- Update to 5.10.0 final
  * New bugfix release
* Sun Dec  3 2017 fabian@ritter-vogt.de
- Update to 5.10.0 RC 2
  * New bugfix release
* Thu Nov 30 2017 fabian@ritter-vogt.de
- Update to 5.10.0 RC 1
  * New bugfix release
* Sat Nov 25 2017 fabian@ritter-vogt.de
- Update to 5.9.3
  * New bugfix release
  * For more details, see:
    http://code.qt.io/cgit/qt/qtspeech.git/tree/dist/changes-5.9.3/?h=v5.9.3
* Wed Nov 15 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 4
- Contains bugfixes
* Thu Nov  2 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 3
- Contains bugfixes
* Mon Oct 30 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 2
- Contains bugfixes
* Mon Oct  9 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 1
- For more information visit:
    https://blog.qt.io/blog/2017/10/09/qt-5-10-beta-released/
* Mon Oct  9 2017 wbauer@tmo.at
- Work around wrong include directory specification in
  speech-dispatcher's pkgconfig file in Leap 42.x to fix build
* Sun Oct  8 2017 lbeltrame@kde.org
- Update to 5.9.2
  * For more details please see:
    https://blog.qt.io/blog/2017/10/06/qt-5-9-2-released/
* Mon Sep 25 2017 fabian@ritter-vogt.de
- TODO: QTBUG-63415
- Update to 5.10 Alpha 1
- For more information visit:
    https://blog.qt.io/blog/2017/09/13/qt-5-10-alpha-released/
* Sat Aug 26 2017 fabian@ritter-vogt.de
- Run spec-cleaner
- Remove unnecessary empty private-headers-devel package
* Sat Jul  1 2017 lbeltrame@kde.org
- Update to 5.9.1
  * For more details please see:
    http://blog.qt.io/blog/2017/06/30/qt-5-9-1-released/
* Fri Jun  2 2017 jengelh@inai.de
- Summary updates.
* Wed May 31 2017 fabian@ritter-vogt.de
- Update to 5.9.0 final
* Wed May 24 2017 fabian@ritter-vogt.de
- Update to 5.9.0 RC:
  * For more details please see:
    http://lists.qt-project.org/pipermail/announce/2017-May/000115.html
    and https://wiki.qt.io/New_Features_in_Qt_5.9
* Sat Sep 20 2014 hrvoje.senjan@gmail.com
- Activate libqt5-qtspeech package
